@@ -308,22 +308,23 @@ pub(crate) fn get_meminfo_value(value: &str) -> u64 {
 pub(crate) fn logical_address(interface: Option<&str>) -> Result<String, ReadoutError> {
     if let Some(ifname) = interface {
         if let Ok(addresses) = if_addrs::get_if_addrs() {
-            if let Some(address) = addresses
+            let address = addresses
                 .iter()
-                .find(|i| i.name.eq_ignore_ascii_case(ifname))
-            {
-                return Ok(address.ip().to_string());
-            }
+                .find(|i| i.name.eq_ignore_ascii_case(ifname));
+
+            return match address {
+                Some(addr) => Ok(addr.ip().to_string()),
+                _ => Err(ReadoutError::Other(format!(
+                    "\"{}\" doesn't exist.",
+                    ifname
+                ))),
+            };
         }
 
-        return Err(ReadoutError::Other(String::from(
-            "Unable to get local IP address.",
-        )));
-    };
-
-    Err(ReadoutError::Other(String::from(
-        "Please specify a network interface to query.",
-    )))
+        Err(ReadoutError::Other(format!("\"{}\" is offline.", ifname)))
+    } else {
+        Err(ReadoutError::Other("No interface specified.".to_owned()))
+    }
 }
 
 pub(crate) fn count_cargo() -> Option<usize> {
